retort v2.5.0 Retort.Sandbox View Source
Generates tokens and redeems those tokens for access to Ecto sandbox, such as
Ecto.Adapters.SQL.Sandbox
Link to this section Summary
Functions
Uses decoded beam metadata to allow the current proceess access to the repo of owner
repo and owner process in a versioned format
Link to this section Functions
Link to this function
allow_access(sandbox \\ Ecto.Adapters.SQL.Sandbox, token)
allow_access(module, %{owner: pid, repo: module}) :: :ok
Uses decoded beam metadata to allow the current proceess access to the repo of owner.
repo and owner process in a versioned format